# artemis_sg

```{toctree}
:titlesonly:
pages/index
guides/index

:caption: API

api/artemis_sg
```

```{include} ../README.md
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
